@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend OPcache                                                         |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2013 The PHP Group                                |
+   | Copyright (c) 1998-2015 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -338,6 +338,7 @@ const char *accel_new_interned_string(const char *arKey, int nKeyLength, int fre
 	if (ZCSG(interned_strings_top) + ZEND_MM_ALIGNED_SIZE(sizeof(Bucket) + nKeyLength) >=
 	    ZCSG(interned_strings_end)) {
 	    /* no memory, return the same non-interned string */
+		zend_accel_error(ACCEL_LOG_WARNING, "Interned string buffer overflow");
 		return arKey;
 	}
 
@@ -572,7 +573,7 @@ static inline void kill_all_lockers(struct flock *mem_usage_check)
 	ZCSG(force_restart_time) = 0;
 	while (mem_usage_check->l_pid > 0) {
 		while (tries--) {
-			zend_accel_error(ACCEL_LOG_INFO, "Killed locker %d", mem_usage_check->l_pid);
+			zend_accel_error(ACCEL_LOG_ERROR, "Killed locker %d", mem_usage_check->l_pid);
 			if (kill(mem_usage_check->l_pid, SIGKILL)) {
 				break;
 			}
@@ -585,7 +586,7 @@ static inline void kill_all_lockers(struct flock *mem_usage_check)
 			usleep(10000);
 		}
 		if (!tries) {
-			zend_accel_error(ACCEL_LOG_INFO, "Can't kill %d after 20 tries!", mem_usage_check->l_pid);
+			zend_accel_error(ACCEL_LOG_ERROR, "Can't kill %d after 20 tries!", mem_usage_check->l_pid);
 			ZCSG(force_restart_time) = time(NULL); /* restore forced restart request */
 		}
 
@@ -880,12 +881,12 @@ static inline int do_validate_timestamps(zend_persistent_script *persistent_scri
 int validate_timestamp_and_record(zend_persistent_script *persistent_script, zend_file_handle *file_handle TSRMLS_DC)
 {
 	if (ZCG(accel_directives).revalidate_freq &&
-	    (persistent_script->dynamic_members.revalidate >= ZCSG(revalidate_at))) {
+	    persistent_script->dynamic_members.revalidate >= ZCG(request_time)) {
 		return SUCCESS;
 	} else if (do_validate_timestamps(persistent_script, file_handle TSRMLS_CC) == FAILURE) {
 		return FAILURE;
 	} else {
-		persistent_script->dynamic_members.revalidate = ZCSG(revalidate_at);
+		persistent_script->dynamic_members.revalidate = ZCG(request_time) + ZCG(accel_directives).revalidate_freq;
 		return SUCCESS;
 	}
 }
@@ -1112,7 +1113,9 @@ static void zend_accel_add_key(char *key, unsigned int key_length, zend_accel_ha
 			char *new_key = zend_shared_alloc(key_length + 1);
 			if (new_key) {
 				memcpy(new_key, key, key_length + 1);
-				zend_accel_hash_update(&ZCSG(hash), new_key, key_length + 1, 1, bucket);
+				if (zend_accel_hash_update(&ZCSG(hash), new_key, key_length + 1, 1, bucket)) {
+					zend_accel_error(ACCEL_LOG_INFO, "Added key '%s'", new_key);
+				}
 			} else {
 				zend_accel_schedule_restart_if_necessary(ACCEL_RESTART_OOM TSRMLS_CC);
 			}
@@ -1196,16 +1199,21 @@ static zend_persistent_script *cache_script_in_shared_memory(zend_persistent_scr
 
 	/* store script structure in the hash table */
 	bucket = zend_accel_hash_update(&ZCSG(hash), new_persistent_script->full_path, new_persistent_script->full_path_len + 1, 0, new_persistent_script);
-	if (bucket && !ZCG(accel_directives).revalidate_path &&
-	    /* key may contain non-persistent PHAR aliases (see issues #115 and #149) */
-	    memcmp(key, "phar://", sizeof("phar://") - 1) != 0 &&
-	    (new_persistent_script->full_path_len != key_length ||
-	     memcmp(new_persistent_script->full_path, key, key_length) != 0)) {
-		/* link key to the same persistent script in hash table */
-		if (!zend_accel_hash_update(&ZCSG(hash), key, key_length + 1, 1, bucket)) {
-			zend_accel_error(ACCEL_LOG_DEBUG, "No more entries in hash table!");
-			ZSMMG(memory_exhausted) = 1;
-			zend_accel_schedule_restart_if_necessary(ACCEL_RESTART_HASH TSRMLS_CC);
+	if (bucket) {
+		zend_accel_error(ACCEL_LOG_INFO, "Cached script '%s'", new_persistent_script->full_path);
+		if (!ZCG(accel_directives).revalidate_path &&
+		    /* key may contain non-persistent PHAR aliases (see issues #115 and #149) */
+		    memcmp(key, "phar://", sizeof("phar://") - 1) != 0 &&
+		    (new_persistent_script->full_path_len != key_length ||
+		     memcmp(new_persistent_script->full_path, key, key_length) != 0)) {
+			/* link key to the same persistent script in hash table */
+			if (zend_accel_hash_update(&ZCSG(hash), key, key_length + 1, 1, bucket)) {
+				zend_accel_error(ACCEL_LOG_INFO, "Added key '%s'", key);
+			} else {
+				zend_accel_error(ACCEL_LOG_DEBUG, "No more entries in hash table!");
+				ZSMMG(memory_exhausted) = 1;
+				zend_accel_schedule_restart_if_necessary(ACCEL_RESTART_HASH TSRMLS_CC);
+			}
 		}
 	}
 
@@ -1441,7 +1449,7 @@ static zend_persistent_script *compile_and_cache_file(zend_file_handle *file_han
 		 * otherwise we have a race-condition.
 		 */
 		new_persistent_script->timestamp = timestamp;
-		new_persistent_script->dynamic_members.revalidate = ZCSG(revalidate_at);
+		new_persistent_script->dynamic_members.revalidate = ZCG(request_time) + ZCG(accel_directives).revalidate_freq;
 	}
 
 	if (file_handle->opened_path) {
@@ -2128,7 +2136,9 @@ static void accel_activate(void)
 				}
 
 #if (ZEND_EXTENSION_API_NO > PHP_5_3_X_API_NO) && !defined(ZTS)
-				accel_interned_strings_restore_state(TSRMLS_C);
+				if (ZCG(accel_directives).interned_strings_buffer) {
+					accel_interned_strings_restore_state(TSRMLS_C);
+				}
 #endif
 
 				zend_shared_alloc_restore_state();
@@ -2145,13 +2155,6 @@ static void accel_activate(void)
 		zend_accel_error(ACCEL_LOG_WARNING, "Internal functions count changed - was %d, now %d", ZCG(internal_functions_count), zend_hash_num_elements(&ZCG(function_table)));
 	}
 
-	if (ZCG(accel_directives).validate_timestamps) {
-		time_t now = ZCG(request_time);
-		if (now > ZCSG(revalidate_at) + (time_t)ZCG(accel_directives).revalidate_freq) {
-			ZCSG(revalidate_at) = now;
-		}
-	}
-
 	ZCG(cwd) = NULL;
 
 	SHM_PROTECT();
@@ -2446,36 +2449,39 @@ static int zend_accel_init_shm(TSRMLS_D)
 
 #if ZEND_EXTENSION_API_NO > PHP_5_3_X_API_NO
 
+	ZCSG(interned_strings_start) = ZCSG(interned_strings_end) = NULL;
 # ifndef ZTS
 	zend_hash_init(&ZCSG(interned_strings), (ZCG(accel_directives).interned_strings_buffer * 1024 * 1024) / (sizeof(Bucket) + sizeof(Bucket*) + 8 /* average string length */), NULL, NULL, 1);
-	ZCSG(interned_strings).nTableMask = ZCSG(interned_strings).nTableSize - 1;
-	ZCSG(interned_strings).arBuckets = zend_shared_alloc(ZCSG(interned_strings).nTableSize * sizeof(Bucket *));
-	ZCSG(interned_strings_start) = zend_shared_alloc((ZCG(accel_directives).interned_strings_buffer * 1024 * 1024));
-	if (!ZCSG(interned_strings).arBuckets || !ZCSG(interned_strings_start)) {
-		zend_accel_error(ACCEL_LOG_FATAL, ACCELERATOR_PRODUCT_NAME " cannot allocate buffer for interned strings");
-		return FAILURE;
+	if (ZCG(accel_directives).interned_strings_buffer) {
+		ZCSG(interned_strings).nTableMask = ZCSG(interned_strings).nTableSize - 1;
+		ZCSG(interned_strings).arBuckets = zend_shared_alloc(ZCSG(interned_strings).nTableSize * sizeof(Bucket *));
+		ZCSG(interned_strings_start) = zend_shared_alloc((ZCG(accel_directives).interned_strings_buffer * 1024 * 1024));
+		if (!ZCSG(interned_strings).arBuckets || !ZCSG(interned_strings_start)) {
+			zend_accel_error(ACCEL_LOG_FATAL, ACCELERATOR_PRODUCT_NAME " cannot allocate buffer for interned strings");
+			return FAILURE;
+		}
+		ZCSG(interned_strings_end)   = ZCSG(interned_strings_start) + (ZCG(accel_directives).interned_strings_buffer * 1024 * 1024);
+		ZCSG(interned_strings_top)   = ZCSG(interned_strings_start);
+
+		orig_interned_strings_start = CG(interned_strings_start);
+		orig_interned_strings_end = CG(interned_strings_end);
+		CG(interned_strings_start) = ZCSG(interned_strings_start);
+		CG(interned_strings_end) = ZCSG(interned_strings_end);
 	}
-	ZCSG(interned_strings_end)   = ZCSG(interned_strings_start) + (ZCG(accel_directives).interned_strings_buffer * 1024 * 1024);
-	ZCSG(interned_strings_top)   = ZCSG(interned_strings_start);
-# else
-	ZCSG(interned_strings_start) = ZCSG(interned_strings_end) = NULL;
 # endif
 
-	orig_interned_strings_start = CG(interned_strings_start);
-	orig_interned_strings_end = CG(interned_strings_end);
 	orig_new_interned_string = zend_new_interned_string;
 	orig_interned_strings_snapshot = zend_interned_strings_snapshot;
 	orig_interned_strings_restore = zend_interned_strings_restore;
-
-	CG(interned_strings_start) = ZCSG(interned_strings_start);
-	CG(interned_strings_end) = ZCSG(interned_strings_end);
 	zend_new_interned_string = accel_new_interned_string_for_php;
 	zend_interned_strings_snapshot = accel_interned_strings_snapshot_for_php;
 	zend_interned_strings_restore = accel_interned_strings_restore_for_php;
 
 # ifndef ZTS
-	accel_use_shm_interned_strings(TSRMLS_C);
-	accel_interned_strings_save_state(TSRMLS_C);
+	if (ZCG(accel_directives).interned_strings_buffer) {
+		accel_use_shm_interned_strings(TSRMLS_C);
+		accel_interned_strings_save_state(TSRMLS_C);
+	}
 # endif
 
 #endif
@@ -2609,10 +2615,6 @@ static int accel_startup(zend_extension *extension)
 	zend_resolve_path = persistent_zend_resolve_path;
 #endif
 
-	if (ZCG(accel_directives).validate_timestamps) {
-		ZCSG(revalidate_at) = zend_accel_get_time() + ZCG(accel_directives).revalidate_freq;
-	}
-
 	/* Override chdir() function */
 	if (zend_hash_find(CG(function_table), "chdir", sizeof("chdir"), (void**)&func) == SUCCESS &&
 	    func->type == ZEND_INTERNAL_FUNCTION) {
@@ -2700,6 +2702,21 @@ void accel_shutdown(TSRMLS_D)
 		return;
 	}
 
+#if ZEND_EXTENSION_API_NO > PHP_5_3_X_API_NO
+	if (ZCG(accel_directives).interned_strings_buffer) {
+# ifndef ZTS
+		zend_hash_clean(CG(function_table));
+		zend_hash_clean(CG(class_table));
+		zend_hash_clean(EG(zend_constants));
+# endif
+		CG(interned_strings_start) = orig_interned_strings_start;
+		CG(interned_strings_end) = orig_interned_strings_end;
+	}
+	zend_new_interned_string = orig_new_interned_string;
+	zend_interned_strings_snapshot = orig_interned_strings_snapshot;
+	zend_interned_strings_restore = orig_interned_strings_restore;
+#endif
+
 	accel_free_ts_resources();
 	zend_shared_alloc_shutdown();
 	zend_compile_file = accelerator_orig_compile_file;
@@ -2707,20 +2724,6 @@ void accel_shutdown(TSRMLS_D)
 	if (zend_hash_find(EG(ini_directives), "include_path", sizeof("include_path"), (void **) &ini_entry) == SUCCESS) {
 		ini_entry->on_modify = orig_include_path_on_modify;
 	}
-
-#if ZEND_EXTENSION_API_NO > PHP_5_3_X_API_NO
-# ifndef ZTS
-	zend_hash_clean(CG(function_table));
-	zend_hash_clean(CG(class_table));
-	zend_hash_clean(EG(zend_constants));
-# endif
-	CG(interned_strings_start) = orig_interned_strings_start;
-	CG(interned_strings_end) = orig_interned_strings_end;
-	zend_new_interned_string = orig_new_interned_string;
-	zend_interned_strings_snapshot = orig_interned_strings_snapshot;
-	zend_interned_strings_restore = orig_interned_strings_restore;
-#endif
-
 }
 
 void zend_accel_schedule_restart(zend_accel_restart_reason reason TSRMLS_DC)
@@ -2803,7 +2806,7 @@ ZEND_EXT_API zend_extension zend_extension_entry = {
 	ACCELERATOR_VERSION,					/* version */
 	"Zend Technologies",					/* author */
 	"http://www.zend.com/",					/* URL */
-	"Copyright (c) 1999-2013",				/* copyright */
+	"Copyright (c) 1999-2015",				/* copyright */
 	accel_startup,					   		/* startup */
 	NULL,									/* shutdown */
 	accel_activate,							/* per-script activation */
